==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-admin/lxqt-admin-time/lxqt-admin-time_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="32"/>
        <source>Time and date setup</source>
        <translation>Dátum és időbeállítás</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>Time:</source>
        <translation>Idő:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="55"/>
        <source>HH:mm:ss</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="69"/>
        <source>Date:</source>
        <translation>Dátum:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="105"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Változtatások csak rendszergazdaként menthetők,&lt;br&gt;jelszóbekérés a kilépés után.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="42"/>
        <source>Time and date configuration</source>
        <translation>Dátum és időbeállítások</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="53"/>
        <source>Date and time</source>
        <translation>Dátum és idő</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="62"/>
        <source>Timezone</source>
        <translation>Időzóna</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="162"/>
        <source>Authentication Error</source>
        <translation>Hitelesítési hiba</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="14"/>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="26"/>
        <source>Timezone setup</source>
        <translation>Időzóna beállítás</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="35"/>
        <source>Your current timezone:</source>
        <translation>Mostani időzóna:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="42"/>
        <source>TextLabel</source>
        <translation>Szövegcím</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="51"/>
        <source>Filter</source>
        <translation>Szűrő</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Változtatások csak rendszergazdaként menthetők,&lt;br&gt;jelszóbekérés a kilépés után.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-time/lxqt-admin-time_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>DateTime</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Űrlap</translation>
    </message>
    <message>
        <source>Time and date setup</source>
        <translation type="vanished">Dátum és időbeállítás</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Idő:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Dátum:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="89"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Változtatások csak rendszergazdaként menthetők,&lt;br&gt;jelszóbekérés a kilépés után.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="42"/>
        <source>Time and date configuration</source>
        <translation>Dátum és időbeállítások</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="53"/>
        <source>Date and time</source>
        <translation>Dátum és idő</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="62"/>
        <source>Timezone</source>
        <translation>Időzóna</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="162"/>
        <source>Authentication Error</source>
        <translation>Hitelesítési hiba</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <source>Form</source>
        <translation type="vanished">Űrlap</translation>
    </message>
    <message>
        <source>Timezone setup</source>
        <translation type="vanished">Időzóna beállítás</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Mostani időzóna:</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="26"/>
        <source>TextLabel</source>
        <translation>Szövegcím</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="35"/>
        <source>Filter</source>
        <translation>Szűrő</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="54"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Változtatások csak rendszergazdaként menthetők,&lt;br&gt;jelszóbekérés a kilépés után.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
</context>
</TS>
